@@ -31,7 +31,7 @@ extern jmp_buf error_jmp_buffer;
 /* Print error message and die
    If fmt ends in colon, include system error information */
 void eprintf(const char *fmt, const char *file, int line,
-             ...) CK_ATTRIBUTE_NORETURN CK_ATTRIBUTE_FORMAT(gnu_printf, 1, 4);
+             ...) CK_ATTRIBUTE_NORETURN CK_ATTRIBUTE_FORMAT(printf, 1, 4);
 /* malloc or die */
 void *emalloc(size_t n);
 void *erealloc(void *, size_t n);
