@@ -1,3 +1,23 @@
+/*
+ * Check: a unit test framework for C
+ * Copyright (C) 2001, 2002 Arien Malec
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+
 #include "../lib/libcompat.h"
 
 #include <stdio.h>
@@ -52,6 +72,12 @@ static void selective_setup (void)
   suite_add_tcase (s1, tc11);
   suite_add_tcase (s1, tc12);
   
+  /* This line intentionally attempts to add an already
+   * added test case twice, to ensure it is not added
+   * again. If it was added again, when the test cases
+   * are freed a double-free failure will occur. */
+  suite_add_tcase (s1, tc12);
+
   /*
    * Create a test suite 'suite2' with one test case 'test21'
    * containing two tests.
