@@ -1,3 +1,23 @@
+/*
+ * Check: a unit test framework for C
+ * Copyright (C) 2001, 2002 Arien Malec
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+
 /**
  * The purpose of this test is to be used by valgrind to check for
  * memory leaks. Each public API that check exports is used at
@@ -12,9 +32,9 @@
 #include "config.h"
 #include "check_check.h"
 
-int main ()
+int main (void)
 {
-    int n;
+    int number_failed;
     SRunner *sr;
 
     /*
@@ -47,7 +67,7 @@ int main ()
 #if defined(HAVE_FORK) && HAVE_FORK==1
     srunner_add_suite(sr, make_exit_suite());
 #endif
-
+    srunner_add_suite(sr, make_tag_suite());
     srunner_add_suite(sr, make_selective_suite());
 
     /*
@@ -63,8 +83,8 @@ int main ()
     /* Cleanup from the fork suite setup */
     fork_teardown();
 
-    n = srunner_ntests_failed(sr);
+    number_failed = srunner_ntests_failed(sr);
     srunner_free(sr);
-    return (n == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+    return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
 
