@@ -1,3 +1,23 @@
+/*
+ * Check: a unit test framework for C
+ * Copyright (C) 2001, 2002 Arien Malec
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+
 #include "../lib/libcompat.h"
 
 #include <stdlib.h>
@@ -56,7 +76,7 @@ END_TEST
 int
 main (void)
 {
-  int nf;
+  int number_failed;
   s = suite_create ("ForkThreadStress");
   tc = tcase_create ("ForkThreadStress");
   sr = srunner_create (s);
@@ -71,13 +91,13 @@ main (void)
 #endif /* HAVE_FORK */
 
   srunner_run_all (sr, CK_VERBOSE);
-  nf = srunner_ntests_failed (sr);
+  number_failed = srunner_ntests_failed (sr);
   srunner_free (sr);
 
   /* hack to give us XFAIL on non-posix platforms */
 #ifndef HAVE_FORK
-  nf++;
+  number_failed++;
 #endif /* !HAVE_FORK */
 
-  return nf ? EXIT_FAILURE : EXIT_SUCCESS;
+  return number_failed ? EXIT_FAILURE : EXIT_SUCCESS;
 }
